==> request-tracker4_4.4.4%2Bdfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/specialchar/dialogs/lang/ug.js <==
﻿/**
 * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'ug', {
	euro: 'ياۋرو بەلگىسى',
	lsquo: 'يالاڭ پەش سول',
	rsquo: 'يالاڭ پەش ئوڭ',
	ldquo: 'قوش پەش سول',
	rdquo: 'قوش پەش ئوڭ',
	ndash: 'سىزىقچە',
	mdash: 'سىزىق',
	iexcl: 'ئۈندەش',
	cent: 'تىيىن بەلگىسى',
	pound: 'فوند ستېرلىڭ',
	curren: 'پۇل بەلگىسى',
	yen: 'ياپونىيە يىنى',
	brvbar: 'ئۈزۈك بالداق',
	sect: 'پاراگراف بەلگىسى',
	uml: 'تاۋۇش ئايرىش بەلگىسى',
	copy: 'نەشر ھوقۇقى بەلگىسى',
	ordf: 'Feminine ordinal indicator', // MISSING
	laquo: 'قوش تىرناق سول',
	not: 'غەيرى بەلگە',
	reg: 'خەتلەتكەن تاۋار ماركىسى',
	macr: 'سوزۇش بەلگىسى',
	deg: 'گىرادۇس بەلگىسى',
	sup2: 'يۇقىرى ئىندېكىس 2',
	sup3: 'يۇقىرى ئىندېكىس 3',
	acute: 'ئۇرغۇ بەلگىسى',
	micro: 'Micro sign', // MISSING
	para: 'ئابزاس بەلگىسى',
	middot: 'ئوتتۇرا چېكىت',
	cedil: 'ئاستىغا قوشۇلىدىغان بەلگە',
	sup1: 'يۇقىرى ئىندېكىس 1',
	ordm: 'Masculine ordinal indicator', // MISSING
	raquo: 'قوش تىرناق ئوڭ',
	frac14: 'ئاددىي كەسىر تۆتتىن بىر',
	frac12: 'ئاددىي كەسىر ئىككىدىن بىر',
	frac34: 'ئاددىي كەسىر ئۈچتىن تۆرت',
	iquest: 'Inverted question mark', // MISSING
	Agrave: 'Latin capital letter A with grave accent', // MISSING
	Aacute: 'Latin capital letter A with acute accent', // MISSING
	Acirc: 'Latin capital letter A with circumflex', // MISSING
	Atilde: 'Latin capital letter A with tilde', // MISSING
	Auml: 'Latin capital letter A with diaeresis', // MISSING
	Aring: 'Latin capital letter A with ring above', // MISSING
	AElig: 'Latin Capital letter Æ', // MISSING
	Ccedil: 'Latin capital letter C with cedilla', // MISSING
	Egrave: 'Latin capital letter E with grave accent', // MISSING
	Eacute: 'Latin capital letter E with acute accent', // MISSING
	Ecirc: 'Latin capital letter E with circumflex', // MISSING
	Euml: 'Latin capital letter E with diaeresis', // MISSING
	Igrave: 'Latin capital letter I with grave accent', // MISSING
	Iacute: 'Latin capital letter I with acute accent', // MISSING
	Icirc: 'Latin capital letter I with circumflex', // MISSING
	Iuml: 'Latin capital letter I with diaeresis', // MISSING
	ETH: 'Latin capital letter Eth', // MISSING
	Ntilde: 'Latin capital letter N with tilde', // MISSING
	Ograve: 'قوش پەش ئوڭ',
	Oacute: 'Latin capital letter O with acute accent', // MISSING
	Ocirc: 'Latin capital letter O with circumflex', // MISSING
	Otilde: 'Latin capital letter O with tilde', // MISSING
	Ouml: 'Latin capital letter O with diaeresis', // MISSING
	times: 'Multiplication sign', // MISSING
	Oslash: 'Latin capital letter O with stroke', // MISSING
	Ugrave: 'Latin capital letter U with grave accent', // MISSING
	Uacute: 'Latin capital letter U with acute accent', // MISSING
	Ucirc: 'Latin capital letter U with circumflex', // MISSING
	Uuml: 'Latin capital letter U with diaeresis', // MISSING
	Yacute: 'Latin capital letter Y with acute accent', // MISSING
	THORN: 'Latin capital letter Thorn', // MISSING
	szlig: 'Latin small letter sharp s', // MISSING
	agrave: 'Latin small letter a with grave accent', // MISSING
	aacute: 'Latin small letter a with acute accent', // MISSING
	acirc: 'Latin small letter a with circumflex', // MISSING
	atilde: 'Latin small letter a with tilde', // MISSING
	auml: 'Latin small letter a with diaeresis', // MISSING
	aring: 'Latin small letter a with ring above', // MISSING
	aelig: 'Latin small letter æ', // MISSING
	ccedil: 'Latin small letter c with cedilla', // MISSING
	egrave: 'Latin small letter e with grave accent', // MISSING
	eacute: 'Latin small letter e with acute accent', // MISSING
	ecirc: 'Latin small letter e with circumflex', // MISSING
	euml: 'Latin small letter e with diaeresis', // MISSING
	igrave: 'Latin small letter i with grave accent', // MISSING
	iacute: 'Latin small letter i with acute accent', // MISSING
	icirc: 'Latin small letter i with circumflex', // MISSING
	iuml: 'Latin small letter i with diaeresis', // MISSING
	eth: 'Latin small letter eth', // MISSING
	ntilde: 'تىك موللاق سوئال بەلگىسى',
	ograve: 'Latin small letter o with grave accent', // MISSING
	oacute: 'Latin small letter o with acute accent', // MISSING
	ocirc: 'Latin small letter o with circumflex', // MISSING
	otilde: 'Latin small letter o with tilde', // MISSING
	ouml: 'Latin small letter o with diaeresis', // MISSING
	divide: 'بۆلۈش بەلگىسى',
	oslash: 'Latin small letter o with stroke', // MISSING
	ugrave: 'Latin small letter u with grave accent', // MISSING
	uacute: 'Latin small letter u with acute accent', // MISSING
	ucirc: 'Latin small letter u with circumflex', // MISSING
	uuml: 'Latin small letter u with diaeresis', // MISSING
	yacute: 'Latin small letter y with acute accent', // MISSING
	thorn: 'Latin small letter thorn', // MISSING
	yuml: 'Latin small letter y with diaeresis', // MISSING
	OElig: 'Latin capital ligature OE', // MISSING
	oelig: 'Latin small ligature oe', // MISSING
	'372': 'Latin capital letter W with circumflex', // MISSING
	'374': 'Latin capital letter Y with circumflex', // MISSING
	'373': 'Latin small letter w with circumflex', // MISSING
	'375': 'Latin small letter y with circumflex', // MISSING
	sbquo: 'Single low-9 quotation mark', // MISSING
	'8219': 'Single high-reversed-9 quotation mark', // MISSING
	bdquo: 'Double low-9 quotation mark', // MISSING
	hellip: 'Horizontal ellipsis', // MISSING
	trade: 'خەتلەتكەن تاۋار ماركىسى بەلگىسى',
	'9658': 'Black right-pointing pointer', // MISSING
	bull: 'Bullet', // MISSING
	rarr: 'ئوڭ يا ئوق',
	rArr: 'ئوڭ قوش سىزىق يا ئوق',
	hArr: 'ئوڭ سول قوش سىزىق يا ئوق',
	diams: 'ئۇيۇل غىچ',
	asymp: 'تەخمىنەن تەڭ'
} );

==> request-tracker5_5.0.3%2Bdfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/specialchar/dialogs/lang/ug.js <==
/**
 * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'ug', {
	euro: 'ياۋرو بەلگىسى',
	lsquo: 'يالاڭ پەش سول',
	rsquo: 'يالاڭ پەش ئوڭ',
	ldquo: 'قوش پەش سول',
	rdquo: 'قوش پەش ئوڭ',
	ndash: 'سىزىقچە',
	mdash: 'سىزىق',
	iexcl: 'ئۈندەش',
	cent: 'تىيىن بەلگىسى',
	pound: 'فوند ستېرلىڭ',
	curren: 'پۇل بەلگىسى',
	yen: 'ياپونىيە يىنى',
	brvbar: 'ئۈزۈك بالداق',
	sect: 'پاراگراف بەلگىسى',
	uml: 'تاۋۇش ئايرىش بەلگىسى',
	copy: 'نەشر ھوقۇقى بەلگىسى',
	ordf: 'Feminine ordinal indicator', // MISSING
	laquo: 'قوش تىرناق سول',
	not: 'غەيرى بەلگە',
	reg: 'خەتلەتكەن تاۋار ماركىسى',
	macr: 'سوزۇش بەلگىسى',
	deg: 'گىرادۇس بەلگىسى',
	sup2: 'يۇقىرى ئىندېكىس 2',
	sup3: 'يۇقىرى ئىندېكىس 3',
	acute: 'ئۇرغۇ بەلگىسى',
	micro: 'Micro sign', // MISSING
	para: 'ئابزاس بەلگىسى',
	middot: 'ئوتتۇرا چېكىت',
	cedil: 'ئاستىغا قوشۇلىدىغان بەلگە',
	sup1: 'يۇقىرى ئىندېكىس 1',
	ordm: 'Masculine ordinal indicator', // MISSING
	raquo: 'قوش تىرناق ئوڭ',
	frac14: 'ئاددىي كەسىر تۆتتىن بىر',
	frac12: 'ئاددىي كەسىر ئىككىدىن بىر',
	frac34: 'ئاددىي كەسىر ئۈچتىن تۆرت',
	iquest: 'Inverted question mark', // MISSING
	Agrave: 'Latin capital letter A with grave accent', // MISSING
	Aacute: 'Latin capital letter A with acute accent', // MISSING
	Acirc: 'Latin capital letter A with circumflex', // MISSING
	Atilde: 'Latin capital letter A with tilde', // MISSING
	Auml: 'Latin capital letter A with diaeresis', // MISSING
	Aring: 'Latin capital letter A with ring above', // MISSING
	AElig: 'Latin capital letter Æ', // MISSING
	Ccedil: 'Latin capital letter C with cedilla', // MISSING
	Egrave: 'Latin capital letter E with grave accent', // MISSING
	Eacute: 'Latin capital letter E with acute accent', // MISSING
	Ecirc: 'Latin capital letter E with circumflex', // MISSING
	Euml: 'Latin capital letter E with diaeresis', // MISSING
	Igrave: 'Latin capital letter I with grave accent', // MISSING
	Iacute: 'Latin capital letter I with acute accent', // MISSING
	Icirc: 'Latin capital letter I with circumflex', // MISSING
	Iuml: 'Latin capital letter I with diaeresis', // MISSING
	ETH: 'Latin capital letter Eth', // MISSING
	Ntilde: 'Latin capital letter N with tilde', // MISSING
	Ograve: 'قوش پەش ئوڭ',
	Oacute: 'Latin capital letter O with acute accent', // MISSING
	Ocirc: 'Latin capital letter O with circumflex', // MISSING
	Otilde: 'Latin capital letter O with tilde', // MISSING
	Ouml: 'Latin capital letter O with diaeresis', // MISSING
	times: 'Multiplication sign', // MISSING
	Oslash: 'Latin capital letter O with stroke', // MISSING
	Ugrave: 'Latin capital letter U with grave accent', // MISSING
	Uacute: 'Latin capital letter U with acute accent', // MISSING
	Ucirc: 'Latin capital letter U with circumflex', // MISSING
	Uuml: 'Latin capital letter U with diaeresis', // MISSING
	Yacute: 'Latin capital letter Y with acute accent', // MISSING
	THORN: 'Latin capital letter Thorn', // MISSING
	szlig: 'Latin small letter sharp s', // MISSING
	agrave: 'Latin small letter a with grave accent', // MISSING
	aacute: 'Latin small letter a with acute accent', // MISSING
	acirc: 'Latin small letter a with circumflex', // MISSING
	atilde: 'Latin small letter a with tilde', // MISSING
	auml: 'Latin small letter a with diaeresis', // MISSING
	aring: 'Latin small letter a with ring above', // MISSING
	aelig: 'Latin small letter æ', // MISSING
	ccedil: 'Latin small letter c with cedilla', // MISSING
	egrave: 'Latin small letter e with grave accent', // MISSING
	eacute: 'Latin small letter e with acute accent', // MISSING
	ecirc: 'Latin small letter e with circumflex', // MISSING
	euml: 'Latin small letter e with diaeresis', // MISSING
	igrave: 'Latin small letter i with grave accent', // MISSING
	iacute: 'Latin small letter i with acute accent', // MISSING
	icirc: 'Latin small letter i with circumflex', // MISSING
	iuml: 'Latin small letter i with diaeresis', // MISSING
	eth: 'Latin small letter eth', // MISSING
	ntilde: 'تىك موللاق سوئال بەلگىسى',
	ograve: 'Latin small letter o with grave accent', // MISSING
	oacute: 'Latin small letter o with acute accent', // MISSING
	ocirc: 'Latin small letter o with circumflex', // MISSING
	otilde: 'Latin small letter o with tilde', // MISSING
	ouml: 'Latin small letter o with diaeresis', // MISSING
	divide: 'بۆلۈش بەلگىسى',
	oslash: 'Latin small letter o with stroke', // MISSING
	ugrave: 'Latin small letter u with grave accent', // MISSING
	uacute: 'Latin small letter u with acute accent', // MISSING
	ucirc: 'Latin small letter u with circumflex', // MISSING
	uuml: 'Latin small letter u with diaeresis', // MISSING
	yacute: 'Latin small letter y with acute accent', // MISSING
	thorn: 'Latin small letter thorn', // MISSING
	yuml: 'Latin small letter y with diaeresis', // MISSING
	OElig: 'Latin capital ligature OE', // MISSING
	oelig: 'Latin small ligature oe', // MISSING
	'372': 'Latin capital letter W with circumflex', // MISSING
	'374': 'Latin capital letter Y with circumflex', // MISSING
	'373': 'Latin small letter w with circumflex', // MISSING
	'375': 'Latin small letter y with circumflex', // MISSING
	sbquo: 'Single low-9 quotation mark', // MISSING
	'8219': 'Single high-reversed-9 quotation mark', // MISSING
	bdquo: 'Double low-9 quotation mark', // MISSING
	hellip: 'Horizontal ellipsis', // MISSING
	trade: 'خەتلەتكەن تاۋار ماركىسى بەلگىسى',
	'9658': 'Black right-pointing pointer', // MISSING
	bull: 'Bullet', // MISSING
	rarr: 'ئوڭ يا ئوق',
	rArr: 'ئوڭ قوش سىزىق يا ئوق',
	hArr: 'ئوڭ سول قوش سىزىق يا ئوق',
	diams: 'ئۇيۇل غىچ',
	asymp: 'تەخمىنەن تەڭ'
} );
